=== modified file 'Makefile.am'
--- Makefile.am	2012-12-27 11:36:56 +0000
+++ Makefile.am	2012-12-29 10:49:09 +0000
@@ -33,6 +33,7 @@
 
 TESTS+= ${check_PROGRAMS} ${check_SCRIPTS}
 
+include yatl/include.am
 include tests/include.am
 include m4/include.am
 include cli/include.am

=== modified file 'configure.ac'
--- configure.ac	2012-12-28 21:23:12 +0000
+++ configure.ac	2012-12-29 10:49:09 +0000
@@ -6,7 +6,7 @@
 # Use and distribution licensed under the BSD license.  See
 # the COPYING file in this directory for full text.
 
-AC_INIT([libdrizzle],[5.1.0])
+AC_INIT([libdrizzle],[5.1.0],[http://bugs.launchpad.net/drizzle],[libdrizzle],[http://drizzle.org/])
 
 AC_CONFIG_AUX_DIR([build-aux])
 
@@ -22,7 +22,6 @@
 
 AC_CONFIG_MACRO_DIR([m4])
 
-
 AC_CONFIG_HEADERS([config.h:config.in])dnl Keep filename to 8.3 for MS-DOS.
 
 AC_CONFIG_SRCDIR([libdrizzle/drizzle.cc])

=== modified file 'tests/include.am'
--- tests/include.am	2012-12-17 11:57:49 +0000
+++ tests/include.am	2012-12-29 10:49:09 +0000
@@ -3,3 +3,5 @@
 # All paths should be given relative to the root
 
 include tests/unit/include.am
+
+noinst_HEADERS+= tests/yatl_lite.h

=== modified file 'tests/unit/binlog.c'
--- tests/unit/binlog.c	2012-12-27 22:20:37 +0000
+++ tests/unit/binlog.c	2012-12-29 10:49:09 +0000
@@ -35,6 +35,8 @@
  *
  */
 
+#include <yatl/lite.h>
+
 #include <libdrizzle-5.1/libdrizzle.h>
 #include "libdrizzle/structs.h"
 #include <stdio.h>
@@ -42,64 +44,46 @@
 #include <stdint.h>
 #include <inttypes.h>
 
-#ifndef EXIT_SKIP
-# define EXIT_SKIP 77
-#endif
-
 int main(int argc, char *argv[])
 {
   (void) argc;
   (void) argv;
-  drizzle_st *con;
-  drizzle_return_t ret;
   drizzle_result_st *result;
 
-  con = drizzle_create_tcp("localhost", 3306, "root", "", "", 0);
-  if (con == NULL)
-  {
-    printf("Drizzle connection object creation error\n");
-    return EXIT_FAILURE;
-  }
-  ret = drizzle_connect(con);
+  drizzle_st *con= drizzle_create_tcp("localhost", 3306, "root", "", "", 0);
+  ASSERT_NOT_NULL_(con, "Drizzle connection object creation error");
+
+  drizzle_return_t ret = drizzle_connect(con);
   if (ret != DRIZZLE_RETURN_OK)
   {
-    printf("Drizzle connection failure\n");
     drizzle_quit(con);
-    return EXIT_SKIP;
+    SKIP_IF_(ret != DRIZZLE_RETURN_OK, "Drizzle connection failure");
   }
 
   result= drizzle_start_binlog(con, 0, "", 0, &ret);
-  if (ret != DRIZZLE_RETURN_OK)
-  {
-    printf("Drizzle binlog start failure\n");
-    return EXIT_FAILURE;
-  }
+  ASSERT_TRUE_(ret == DRIZZLE_RETURN_OK, "Drizzle binlog start failure");
 
   while (ret == DRIZZLE_RETURN_OK)
   {
     uint32_t timestamp;
     ret= drizzle_binlog_get_next_event(result);
     if (ret != DRIZZLE_RETURN_OK)
+    {
       break;
+    }
     timestamp= drizzle_binlog_event_timestamp(result);
     /* Test to see if timestamp is greater than 2012-01-01 00:00:00, corrupted
      * timestamps will have weird values that shoud fail this after several
      * events.  Also rotate event doesn't have a timestamp so need to add 0
      * to this test */
-    if ((timestamp < 1325376000) && (timestamp != 0))
-    {
-      printf("Bad timestamp retrieved: %"PRIu32"\n", timestamp);
-      return EXIT_FAILURE;
-    }
+    ASSERT_FALSE_(((timestamp < 1325376000) && (timestamp != 0)), "Bad timestamp retrieved: %" PRIu32, timestamp);
+
     /* An event higher than the max known is bad, either we don't know about
      * new events or type is corrupted */
-    if (drizzle_binlog_event_type(result) >= DRIZZLE_EVENT_TYPE_END)
-    {
-      printf("Bad event type: %d\n", drizzle_binlog_event_type(result));
-      return EXIT_FAILURE;
-    }
+    ASSERT_FALSE_((drizzle_binlog_event_type(result) >= DRIZZLE_EVENT_TYPE_END), "Bad event type: %d", drizzle_binlog_event_type(result));
   }
 
   drizzle_quit(con);
+
   return EXIT_SUCCESS;
 }

=== modified file 'tests/unit/column.c'
--- tests/unit/column.c	2012-12-28 10:37:41 +0000
+++ tests/unit/column.c	2012-12-29 10:49:09 +0000
@@ -35,133 +35,75 @@
  *
  */
 
+#include <yatl/lite.h>
+
 #include <libdrizzle-5.1/libdrizzle.h>
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 
-#ifndef EXIT_SKIP
-# define EXIT_SKIP 77
-#endif
-
 int main(int argc, char *argv[])
 {
   (void) argc;
   (void) argv;
-  drizzle_st *con;
   drizzle_return_t ret;
   drizzle_result_st *result;
   drizzle_row_t row;
   int num_fields;
 
-  con = drizzle_create_tcp("localhost", 3306, "root", "", "libdrizzle", 0);
-  if (con == NULL)
-  {
-    printf("Drizzle connection object creation error\n");
-    return EXIT_FAILURE;
-  }
+  drizzle_st *con= drizzle_create_tcp("localhost", 3306, "root", "", "libdrizzle", 0);
+  ASSERT_NOT_NULL_(con, "Drizzle connection object creation error");
+
   ret = drizzle_connect(con);
   if (ret != DRIZZLE_RETURN_OK)
   {
-    printf("Drizzle connection failure\n");
     drizzle_quit(con);
-    return EXIT_SKIP;
+    SKIP_IF_(ret != DRIZZLE_RETURN_OK, "Drizzle connection failure");
   }
 
   drizzle_query_str(con, "create table libdrizzle.t1 (a int primary key auto_increment, b varchar(255), c timestamp default current_timestamp)", &ret);
-  if (ret != DRIZZLE_RETURN_OK)
-  {
-    printf("Create table failure\n");
-    return EXIT_FAILURE;
-  }
+  ASSERT_TRUE_(ret == DRIZZLE_RETURN_OK, "create table libdrizzle.t1 (a int primary key auto_increment, b varchar(255), c timestamp default current_timestamp)");
 
   drizzle_query_str(con, "insert into libdrizzle.t1 (b) values ('this'),('is'),('war')", &ret);
-  if (ret != DRIZZLE_RETURN_OK)
-  {
-    printf("Insert failure\n");
-    return EXIT_FAILURE;
-  }
+  ASSERT_TRUE_(ret == DRIZZLE_RETURN_OK, "insert into libdrizzle.t1 (b) values ('this'),('is'),('war')");
 
   result= drizzle_query_str(con, "select * from libdrizzle.t1", &ret);
-  if (ret != DRIZZLE_RETURN_OK)
-  {
-    printf("Select failure\n");
-    return EXIT_FAILURE;
-  }
+  ASSERT_TRUE_(ret == DRIZZLE_RETURN_OK, "select * from libdrizzle.t1");
+
   drizzle_result_buffer(result);
   num_fields= drizzle_result_column_count(result);
 
-  if (num_fields != 3)
-  {
-    printf("Retrieved bad number of fields\n");
-    return EXIT_FAILURE;
-  }
+  ASSERT_TRUE_(num_fields == 3, "Retrieved bad number of fields");
+
   int i= 0;
-  int j= 0;
-  char buf[10];
   drizzle_column_st *column;
   while ((row = drizzle_row_next(result)))
   {
     drizzle_column_seek(result, 0);
-    j= 0;
+    int j= 0;
     i++;
-    snprintf(buf, 10, "%d", i);
-    if (strcmp(row[0], buf) != 0)
-    {
-      printf("Retrieved bad row value\n");
-      return EXIT_FAILURE;
-    }
+    char buf[10];
+    snprintf(buf, sizeof(buf), "%d", i);
+    ASSERT_EQ_(strcmp(row[0], buf), 0, "Retrieved bad row value");
     while ((column= drizzle_column_next(result)))
     {
       j++;
-      if (strcmp(drizzle_column_db(column), "libdrizzle") != 0)
-      {
-        printf("Column has bad DB name\n");
-        return EXIT_FAILURE;
-      }
-      if (strcmp(drizzle_column_table(column), "t1") != 0)
-      {
-        printf("Column had bad table name\n");
-        return EXIT_FAILURE;
-      }
-      if ((j == 2) && (drizzle_column_max_size(column) != 255))
-      {
-        printf("Column max size wrong %lu != 255\n", drizzle_column_max_size(column));
-        return EXIT_FAILURE;
-      }
-      if ((j == 2) && (drizzle_column_charset(column) != DRIZZLE_CHARSET_LATIN1_SWEDISH_CI))
-      {
-        printf("Column type wrong, %d != %d\n", drizzle_column_charset(column), DRIZZLE_CHARSET_UTF8_BIN);
-        return EXIT_FAILURE;
-      }
-      if ((j == 3) && (drizzle_column_type(column) != DRIZZLE_COLUMN_TYPE_TIMESTAMP))
-      {
-        printf("Column type wrong\n");
-        return EXIT_FAILURE;
-      }
-    }
-    if (j != 3)
-    {
-      printf("Wrong column count\n");
-      return EXIT_FAILURE;
-    }
+      ASSERT_EQ_(strcmp(drizzle_column_db(column), "libdrizzle"), 0, "Column has bad DB name");
+      ASSERT_EQ_(strcmp(drizzle_column_table(column), "t1"), 0, "Column had bad table name");
+      ASSERT_FALSE_((j == 2) && (drizzle_column_max_size(column) != 255), "Column max size wrong %lu != 255", drizzle_column_max_size(column));
+
+      ASSERT_FALSE_((j == 2) && (drizzle_column_charset(column) != DRIZZLE_CHARSET_LATIN1_SWEDISH_CI), "Column type wrong, %d != %d", drizzle_column_charset(column), DRIZZLE_CHARSET_UTF8_BIN);
+      ASSERT_FALSE_((j == 3) && (drizzle_column_type(column) != DRIZZLE_COLUMN_TYPE_TIMESTAMP), "Column type wrong");
+    }
+    ASSERT_EQ_(j, 3, "Wrong column count");
   }
   /* Should have had 3 rows */
-  if (i != 3)
-  {
-    printf("Retrieved bad number of rows\n");
-    return EXIT_FAILURE;
-  }
+  ASSERT_EQ_(i, 3, "Retrieved bad number of rows");
 
   drizzle_result_free(result);
 
   drizzle_query_str(con, "drop table libdrizzle.t1", &ret);
-  if (ret != DRIZZLE_RETURN_OK)
-  {
-    printf("Drop table failure\n");
-    return EXIT_FAILURE;
-  }
-
+  ASSERT_EQ_(DRIZZLE_RETURN_OK, ret, "drop table libdrizzle.t1");
 
   drizzle_quit(con);
   return EXIT_SUCCESS;

=== modified file 'tests/unit/connect.c'
--- tests/unit/connect.c	2012-12-27 22:20:37 +0000
+++ tests/unit/connect.c	2012-12-29 10:49:09 +0000
@@ -35,15 +35,13 @@
  *
  */
 
+#include <yatl/lite.h>
+
 #include <libdrizzle-5.1/libdrizzle.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdint.h>
 
-#ifndef EXIT_SKIP
-# define EXIT_SKIP 77
-#endif
-
 int main(int argc, char *argv[])
 {
   (void) argc;
@@ -60,9 +58,8 @@
   ret = drizzle_connect(con);
   if (ret != DRIZZLE_RETURN_OK)
   {
-    printf("Drizzle connection failure\n");
     drizzle_quit(con);
-    return EXIT_SKIP;
+    SKIP_IF_(ret != DRIZZLE_RETURN_OK, "Drizzle connection failure");
   }
 
   drizzle_quit(con);

=== modified file 'tests/unit/escape.c'
--- tests/unit/escape.c	2012-12-26 08:26:59 +0000
+++ tests/unit/escape.c	2012-12-29 10:49:09 +0000
@@ -35,6 +35,8 @@
  *
  */
 
+#include <yatl/lite.h>
+
 #include <libdrizzle-5.1/libdrizzle.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -52,19 +54,11 @@
 
   // Test for data too long
   out_len= drizzle_escape_string(out, 2, in, strlen(in));
-  if (out_len != -1)
-    return EXIT_FAILURE;
+  ASSERT_EQ(out_len, -1);
 
   out_len= drizzle_escape_string(out, 255, in, strlen(in));
-  if (out_len != 17)
-  {
-    printf("Bad hex length output\n");
-    return EXIT_FAILURE;
-  }
-  if (strcmp(out, "escape \\\"this\\\"\\n") != 0)
-  {
-    printf("Bad hex data output\n");
-    return EXIT_FAILURE;
-  }
+  ASSERT_EQ_(out_len, 17, "Bad hex length output %d", out_len);
+  ASSERT_EQ_(strcmp(out, "escape \\\"this\\\"\\n"), 0, "Bad hex data output");
+
   return EXIT_SUCCESS;
 }

=== modified file 'tests/unit/hex.c'
--- tests/unit/hex.c	2012-12-26 08:26:59 +0000
+++ tests/unit/hex.c	2012-12-29 10:49:09 +0000
@@ -35,6 +35,8 @@
  *
  */
 
+#include <yatl/lite.h>
+
 #include <libdrizzle-5.1/libdrizzle.h>
 #include <stdio.h>
 #include <string.h>
@@ -52,23 +54,12 @@
 
   // Test for bad usage
   result= drizzle_hex_string(out, in, 0);
-  if (result)
-  {
-    printf("Bad usage failure\n");
-    return EXIT_FAILURE;
-  }
-
-  result= drizzle_hex_string(out, in, 6);
-  if (!result)
-  {
-    printf("Failed to get result\n");
-    return EXIT_FAILURE;
-  }
-
-  if (strcmp(out, "00FF7F80B9C0") != 0)
-  {
-    printf("Bad result data\n");
-    return EXIT_FAILURE;
-  }
+  ASSERT_EQ_(false, result, "Bad usage of drizzle_hex_string()");
+
+  result= drizzle_hex_string(out, in, sizeof(in));
+  ASSERT_EQ_(true, result, "Failed to get result");
+
+  ASSERT_STREQ_("00FF7F80B9C0", out, "Bad result data from drizzle_hex_string()");
+
   return EXIT_SUCCESS;
 }

=== modified file 'tests/unit/insert_id.c'
--- tests/unit/insert_id.c	2012-12-27 22:20:37 +0000
+++ tests/unit/insert_id.c	2012-12-29 10:49:09 +0000
@@ -35,80 +35,47 @@
  *
  */
 
+#include <yatl/lite.h>
+
 #include <libdrizzle-5.1/libdrizzle.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdint.h>
 #include <inttypes.h>
 
-#ifndef EXIT_SKIP
-# define EXIT_SKIP 77
-#endif
-
 int main(int argc, char *argv[])
 {
   (void) argc;
   (void) argv;
-  drizzle_st *con;
-  drizzle_return_t ret;
-  drizzle_result_st *result;
-
-  con = drizzle_create_tcp("localhost", 3306, "root", "", "libdrizzle", 0);
-  if (con == NULL)
-  {
-    printf("Drizzle connection object creation error\n");
-    return EXIT_FAILURE;
-  }
-  ret = drizzle_connect(con);
+
+  drizzle_st *con= drizzle_create_tcp("localhost", 3306, "root", "", "libdrizzle", 0);
+  ASSERT_NOT_NULL_(con, "Drizzle connection object creation error");
+
+  drizzle_return_t ret= drizzle_connect(con);
   if (ret != DRIZZLE_RETURN_OK)
   {
-    printf("Drizzle connection failure\n");
     drizzle_quit(con);
-    return EXIT_SKIP;
+    SKIP_IF_(ret != DRIZZLE_RETURN_OK, "Drizzle connection failure");
   }
 
   drizzle_query_str(con, "create table libdrizzle.t1 (a int primary key auto_increment, b int)", &ret);
-  if (ret != DRIZZLE_RETURN_OK)
-  {
-    printf("Create table failure\n");
-    return EXIT_FAILURE;
-  }
-
-  result= drizzle_query_str(con, "insert into libdrizzle.t1 (b) values (1),(2),(3)", &ret);
-  if (ret != DRIZZLE_RETURN_OK)
-  {
-    printf("Insert failure\n");
-    return EXIT_FAILURE;
-  }
-
-  if (drizzle_result_insert_id(result) != 1)
-  {
-    printf("Got bad insert_id (expected 1, got %"PRIu64")", drizzle_result_insert_id(result));
-    return EXIT_FAILURE;
-  }
-  drizzle_result_free(result);
-
-  result= drizzle_query_str(con, "insert into libdrizzle.t1 (b) values (4),(5),(6)", &ret);
-  if (ret != DRIZZLE_RETURN_OK)
-  {
-    printf("Insert failure\n");
-    return EXIT_FAILURE;
-  }
-
-  if (drizzle_result_insert_id(result) != 4)
-  {
-    printf("Got bad insert_id (expected 4, got %"PRIu64")", drizzle_result_insert_id(result));
-    return EXIT_FAILURE;
-  }
-  drizzle_result_free(result);
-
-  drizzle_query_str(con, "drop table libdrizzle.t1", &ret);
-  if (ret != DRIZZLE_RETURN_OK)
-  {
-    printf("Drop table failure\n");
-    return EXIT_FAILURE;
-  }
-
+  ASSERT_EQ_(ret, DRIZZLE_RETURN_OK, "create table libdrizzle.t1 (a int primary key auto_increment, b int)");
+
+  drizzle_result_st *result= drizzle_query_str(con, "insert into libdrizzle.t1 (b) values (1),(2),(3)", &ret);
+  ASSERT_EQ_(ret, DRIZZLE_RETURN_OK, "insert into libdrizzle.t1 (b) values (1),(2),(3)");
+  ASSERT_TRUE(result);
+
+  ASSERT_EQ_(drizzle_result_insert_id(result), 1, "Got bad insert_id (expected 1, got %"PRIu64")", drizzle_result_insert_id(result));
+  drizzle_result_free(result);
+
+  result= drizzle_query_str(con, "INSERT INTO libdrizzle.t1 (b) VALUES (4),(5),(6)", &ret);
+  ASSERT_EQ_(ret, DRIZZLE_RETURN_OK, "INSERT INTO libdrizzle.t1 (b) VALUES (4),(5),(6)");
+
+  ASSERT_EQ_(drizzle_result_insert_id(result), 4, "Got bad insert_id (expected 4, got %"PRIu64")", drizzle_result_insert_id(result));
+  drizzle_result_free(result);
+
+  drizzle_query_str(con, "DROP TABLE libdrizzle.t1", &ret);
+  ASSERT_EQ_(ret, DRIZZLE_RETURN_OK, "dROP TABLE failure");
 
   drizzle_quit(con);
   return EXIT_SUCCESS;

=== modified file 'tests/unit/passwd.c'
--- tests/unit/passwd.c	2012-12-26 08:26:59 +0000
+++ tests/unit/passwd.c	2012-12-29 10:49:09 +0000
@@ -35,6 +35,8 @@
  *
  */
 
+#include <yatl/lite.h>
+
 #include <libdrizzle-5.1/libdrizzle.h>
 #include <stdio.h>
 #include <string.h>

=== modified file 'tests/unit/query.c'
--- tests/unit/query.c	2012-12-27 22:20:37 +0000
+++ tests/unit/query.c	2012-12-29 10:49:09 +0000
@@ -35,15 +35,13 @@
  *
  */
 
+#include <yatl/lite.h>
+
 #include <libdrizzle-5.1/libdrizzle.h>
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 
-#ifndef EXIT_SKIP
-# define EXIT_SKIP 77
-#endif
-
 int main(int argc, char *argv[])
 {
   (void) argc;
@@ -63,9 +61,8 @@
   ret = drizzle_connect(con);
   if (ret != DRIZZLE_RETURN_OK)
   {
-    printf("Drizzle connection failure\n");
     drizzle_quit(con);
-    return EXIT_SKIP;
+    SKIP_IF_(ret != DRIZZLE_RETURN_OK, "Drizzle connection failure");
   }
 
   drizzle_query_str(con, "create table libdrizzle.t1 (a int)", &ret);

=== modified file 'tests/unit/row.c'
--- tests/unit/row.c	2012-12-28 10:37:41 +0000
+++ tests/unit/row.c	2012-12-29 10:49:09 +0000
@@ -35,15 +35,13 @@
  *
  */
 
+#include <yatl/lite.h>
+
 #include <libdrizzle-5.1/libdrizzle.h>
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 
-#ifndef EXIT_SKIP
-# define EXIT_SKIP 77
-#endif
-
 int main(int argc, char *argv[])
 {
   (void) argc;
@@ -63,9 +61,8 @@
   ret = drizzle_connect(con);
   if (ret != DRIZZLE_RETURN_OK)
   {
-    printf("Drizzle connection failure\n");
     drizzle_quit(con);
-    return EXIT_SKIP;
+    SKIP_IF_(ret != DRIZZLE_RETURN_OK, "Drizzle connection failure");
   }
 
   drizzle_query_str(con, "create table libdrizzle.t1 (a int)", &ret);

=== modified file 'tests/unit/statement.c'
--- tests/unit/statement.c	2012-12-27 22:20:37 +0000
+++ tests/unit/statement.c	2012-12-29 10:49:09 +0000
@@ -35,6 +35,8 @@
  *
  */
 
+#include <yatl/lite.h>
+
 #include <libdrizzle-5.1/libdrizzle.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -43,10 +45,6 @@
 #include <inttypes.h>
 #include <string.h>
 
-#ifndef EXIT_SKIP
-# define EXIT_SKIP 77
-#endif
-
 int main(int argc, char *argv[])
 {
   (void) argc;
@@ -64,9 +62,8 @@
   ret = drizzle_connect(con);
   if (ret != DRIZZLE_RETURN_OK)
   {
-    printf("Drizzle connection failure\n");
     drizzle_quit(con);
-    return EXIT_SKIP;
+    SKIP_IF_(ret != DRIZZLE_RETURN_OK, "Drizzle connection failure");
   }
 
   drizzle_query_str(con, "create table libdrizzle.t1 (a int)", &ret);

=== modified file 'tests/unit/unbuffered_query.c'
--- tests/unit/unbuffered_query.c	2012-12-27 22:20:37 +0000
+++ tests/unit/unbuffered_query.c	2012-12-29 10:49:09 +0000
@@ -35,15 +35,13 @@
  *
  */
 
+#include <yatl/lite.h>
+
 #include <libdrizzle-5.1/libdrizzle.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-#ifndef EXIT_SKIP
-# define EXIT_SKIP 77
-#endif
-
 int main(int argc, char *argv[])
 {
   (void) argc;
@@ -63,9 +61,8 @@
   ret = drizzle_connect(con);
   if (ret != DRIZZLE_RETURN_OK)
   {
-    printf("Drizzle connection failure\n");
     drizzle_quit(con);
-    return EXIT_SKIP;
+    SKIP_IF_(ret != DRIZZLE_RETURN_OK, "Drizzle connection failure");
   }
 
   drizzle_query_str(con, "create table libdrizzle.t1 (a int)", &ret);

=== modified file 'tests/unit/version.c'
--- tests/unit/version.c	2012-12-26 08:26:59 +0000
+++ tests/unit/version.c	2012-12-29 10:49:09 +0000
@@ -35,18 +35,19 @@
  *
  */
 
+#include <yatl/lite.h>
+
 #include <libdrizzle-5.1/libdrizzle.h>
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <assert.h>
 
 int main(void)
 {
-  // @todo Don't use assert
-  assert(drizzle_version());
-  assert(strtol(LIBDRIZZLE_VERSION_STRING, (char **) NULL, 10));
-  assert(LIBDRIZZLE_VERSION_HEX > 0);
+  ASSERT_TRUE(drizzle_version());
+  ASSERT_TRUE(strtol(LIBDRIZZLE_VERSION_STRING, (char **) NULL, 10));
+  ASSERT_TRUE(LIBDRIZZLE_VERSION_HEX > 0);
+  ASSERT_TRUE(drizzle_bugreport());
 
   return EXIT_SUCCESS;
 }

=== added directory 'yatl'
=== added file 'yatl/include.am'
--- yatl/include.am	1970-01-01 00:00:00 +0000
+++ yatl/include.am	2012-12-29 10:49:09 +0000
@@ -0,0 +1,6 @@
+# vim:ft=automake
+# included from Top Level Makefile.am
+# All paths should be given relative to the root
+
+noinst_HEADERS+= yatl/lite.h
+

=== added file 'yatl/lite.h'
--- yatl/lite.h	1970-01-01 00:00:00 +0000
+++ yatl/lite.h	2012-12-29 10:49:09 +0000
@@ -0,0 +1,320 @@
+/*  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Data Differential YATL (i.e. libtest)  library
+ *
+ *  Copyright (C) 2012 Data Differential, http://datadifferential.com/
+ *
+ *  Redistribution and use in source and binary forms, with or without
+ *  modification, are permitted provided that the following conditions are
+ *  met:
+ *
+ *      * Redistributions of source code must retain the above copyright
+ *  notice, this list of conditions and the following disclaimer.
+ *
+ *      * Redistributions in binary form must reproduce the above
+ *  copyright notice, this list of conditions and the following disclaimer
+ *  in the documentation and/or other materials provided with the
+ *  distribution.
+ *
+ *      * The names of its contributors may not be used to endorse or
+ *  promote products derived from this software without specific prior
+ *  written permission.
+ *
+ *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+ *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ */
+
+#pragma once
+
+#ifdef __cplusplus
+# include <cstddef>
+# include <cstdlib>
+# include <cstring>
+#include <cstdarg>
+#else
+# include <stddef.h>
+# include <stdlib.h>
+# include <stdbool.h>
+# include <string.h>
+# include <stdarg.h>
+#endif
+#ifndef __PRETTY_FUNCTION__
+# define __PRETTY_FUNCTION__ __func__
+#endif
+
+#ifndef EXIT_SKIP
+# define EXIT_SKIP 77
+#endif
+
+static inline bool valgrind_is_caller(void)
+{
+  if (getenv("TESTS_ENVIRONMENT")  && strstr(getenv("TESTS_ENVIRONMENT"), "valgrind"))
+  {
+    return true;
+  }
+
+  return false;
+}
+
+static inline size_t yatl_strlen(const char *s)
+{
+  if (s)
+  {
+    return strlen(s);
+  }
+
+  return (size_t)(0);
+}
+
+static inline int yatl_strcmp(const char *s1, const char *s2, size_t *s1_length, size_t *s2_length)
+{
+  *s1_length= yatl_strlen(s1);
+  *s2_length= yatl_strlen(s2);
+
+  if (*s1_length == 0 &&  *s1_length == *s2_length)
+  {
+    return 0;
+  }
+
+  if (*s1_length == 0 && *s2_length)
+  {
+    return 1;
+  }
+
+  if (*s1_length &&  *s2_length == 0)
+  {
+    return 1;
+  }
+
+  return strcmp(s1, s2);
+}
+
+#define SKIP_IF(__expression) \
+do \
+{ \
+  if ((__expression)) { \
+    fprintf(stderr, "\n%s:%d: %s SKIP '!%s'\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, #__expression);\
+    exit(EXIT_SKIP); \
+  } \
+} while (0)
+
+#define ASSERT_TRUE(__expression) \
+do \
+{ \
+  if (! (__expression)) { \
+    fprintf(stderr, "\n%s:%d: %s Assertion '%s'\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, #__expression);\
+    exit(EXIT_FAILURE); \
+  } \
+} while (0)
+
+#define ASSERT_FALSE(__expression) \
+do \
+{ \
+  if ((__expression)) { \
+    fprintf(stderr, "\n%s:%d: %s Assertion '!%s'\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, #__expression);\
+    exit(EXIT_FAILURE); \
+  } \
+} while (0)
+
+#define ASSERT_NULL_(__expression, ...) \
+do \
+{ \
+  if ((__expression) != NULL) { \
+    size_t ask= snprintf(0, 0, __VA_ARGS__); \
+    ask++; \
+    char *buffer= (char*)malloc(sizeof(char) * ask); \
+    snprintf(buffer, ask, __VA_ARGS__); \
+    fprintf(stderr, "\n%s:%d: %s Assertion '%s' != NULL [ %s ]\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, #__expression, buffer);\
+    free(buffer); \
+    exit(EXIT_FAILURE); \
+  } \
+} while (0)
+
+#define ASSERT_NOT_NULL(__expression) \
+do \
+{ \
+  if ((__expression) == NULL) { \
+    fprintf(stderr, "\n%s:%d: %s Assertion '%s' == NULL\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, #__expression,);\
+    exit(EXIT_FAILURE); \
+  } \
+} while (0)
+
+#define ASSERT_NOT_NULL_(__expression, ...) \
+do \
+{ \
+  if ((__expression) == NULL) { \
+    size_t ask= snprintf(0, 0, __VA_ARGS__); \
+    ask++; \
+    char *buffer= (char*)malloc(sizeof(char) * ask); \
+    snprintf(buffer, ask, __VA_ARGS__); \
+    fprintf(stderr, "\n%s:%d: %s Assertion '%s' == NULL [ %s ]\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, #__expression, buffer);\
+    free(buffer); \
+    exit(EXIT_FAILURE); \
+  } \
+} while (0)
+
+#define SKIP_IF_(__expression, ...) \
+do \
+{ \
+  if ((__expression)) { \
+    size_t ask= snprintf(0, 0, __VA_ARGS__); \
+    ask++; \
+    char *buffer= (char*)malloc(sizeof(char) * ask); \
+    snprintf(buffer, ask, __VA_ARGS__); \
+    fprintf(stdout, "\n%s:%d: %s SKIP '%s' [ %s ]\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, #__expression, buffer); \
+    free(buffer); \
+    exit(EXIT_SKIP); \
+  } \
+} while (0)
+
+#define ASSERT_TRUE_(__expression, ...) \
+do \
+{ \
+  if (! (__expression)) { \
+    size_t ask= snprintf(0, 0, __VA_ARGS__); \
+    ask++; \
+    char *buffer= (char*)malloc(sizeof(char) * ask); \
+    snprintf(buffer, ask, __VA_ARGS__); \
+    fprintf(stderr, "\n%s:%d: %s Assertion '%s' [ %s ]\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, #__expression, buffer); \
+    free(buffer); \
+    exit(EXIT_FAILURE); \
+  } \
+} while (0)
+
+#define ASSERT_EQ(__expected, __actual) \
+do \
+{ \
+  if ((__expected) != (__actual)) { \
+    fprintf(stderr, "\n%s:%d: %s Assertion '%s' != '%s'\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, #__expected, #__actual); \
+    exit(EXIT_FAILURE); \
+  } \
+} while (0)
+
+#define ASSERT_EQ_(__expected, __actual, ...) \
+do \
+{ \
+  if ((__expected) != (__actual)) { \
+    size_t ask= snprintf(0, 0, __VA_ARGS__); \
+    ask++; \
+    char *buffer= (char*)malloc(sizeof(char) * ask); \
+    snprintf(buffer, ask, __VA_ARGS__); \
+    fprintf(stderr, "\n%s:%d: %s Assertion '%s' != '%s' [ %s ]\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, #__expected, #__actual, buffer); \
+    free(buffer); \
+    exit(EXIT_FAILURE); \
+  } \
+} while (0)
+
+#define ASSERT_STREQ(__expected_str, __actual_str) \
+do \
+{ \
+  size_t __expected_length; \
+  size_t __actual_length; \
+  int ret= yatl_strcmp(__expected_str, __actual_str, &__expected_length, &__actual_length); \
+  if (ret) { \
+    fprintf(stderr, "\n%s:%d: %s Assertion '%.*s' != '%.*s'\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, \
+            (int)(__expected_length), (__expected_str), \
+            (int)__actual_length, (__actual_str)) ; \
+    exit(EXIT_FAILURE); \
+  } \
+} while (0)
+
+#define ASSERT_STREQ_(__expected_str, __actual_str, ...) \
+do \
+{ \
+  size_t __expected_length; \
+  size_t __actual_length; \
+  int ret= yatl_strcmp(__expected_str, __actual_str, &__expected_length, &__actual_length); \
+  if (ret) { \
+    size_t ask= snprintf(0, 0, __VA_ARGS__); \
+    ask++; \
+    char *buffer= (char*)malloc(sizeof(char) * ask); \
+    ask= snprintf(buffer, ask, __VA_ARGS__); \
+    fprintf(stderr, "\n%s:%d: %s Assertion '%.*s' != '%.*s' [ %.*s ]\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, \
+            (int)(__expected_length), (__expected_str), \
+            (int)(__actual_length), (__actual_str), \
+            (int)(ask), buffer); \
+    free(buffer); \
+    exit(EXIT_FAILURE); \
+  } \
+} while (0)
+
+#define ASSERT_STRNE(__expected_str, __actual_str) \
+do \
+{ \
+  size_t __expected_length; \
+  size_t __actual_length; \
+  int ret= yatl_strcmp(__expected_str, __actual_str, &__expected_length, &__actual_length); \
+  if (ret == 0) { \
+    fprintf(stderr, "\n%s:%d: %s Assertion '%.*s' == '%.*s'\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, \
+            (int)(__expected_length), (__expected_str), \
+            (int)__actual_length, (__actual_str)) ; \
+    exit(EXIT_FAILURE); \
+  } \
+} while (0)
+
+#define ASSERT_STRNE_(__expected_str, __actual_str, ...) \
+do \
+{ \
+  size_t __expected_length; \
+  size_t __actual_length; \
+  int ret= yatl_strcmp(__expected_str, __actual_str, &__expected_length, &__actual_length); \
+  if (ret == 0) { \
+    size_t ask= snprintf(0, 0, __VA_ARGS__); \
+    ask++; \
+    char *buffer= (char*)malloc(sizeof(char) * ask); \
+    ask= snprintf(buffer, ask, __VA_ARGS__); \
+    fprintf(stderr, "\n%s:%d: %s Assertion '%.*s' == '%.*s' [ %.*s ]\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, \
+            (int)(__expected_length), (__expected_str), \
+            (int)(__actual_length), (__actual_str), \
+            (int)(ask), buffer); \
+    free(buffer); \
+    exit(EXIT_FAILURE); \
+  } \
+} while (0)
+
+#define ASSERT_NEQ(__expected, __actual, ...) \
+do \
+{ \
+  if ((__expected) == (__actual)) { \
+    fprintf(stderr, "\n%s:%d: %s Assertion '%s' == '%s'\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, #__expected, #__actual); \
+    exit(EXIT_FAILURE); \
+  } \
+} while (0)
+
+#define ASSERT_NEQ_(__expected, __actual, ...) \
+do \
+{ \
+  if ((__expected) == (__actual)) { \
+    size_t ask= snprintf(0, 0, __VA_ARGS__); \
+    ask++; \
+    char *buffer= (char*)malloc(sizeof(char) * ask); \
+    snprintf(buffer, ask, __VA_ARGS__); \
+    fprintf(stderr, "\n%s:%d: %s Assertion '%s' == '%s' [ %s ]\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, #__expected, #__actual, buffer); \
+    free(buffer); \
+    exit(EXIT_FAILURE); \
+  } \
+} while (0)
+
+#define ASSERT_FALSE_(__expression, ...) \
+do \
+{ \
+  if ((__expression)) { \
+    size_t ask= snprintf(0, 0, __VA_ARGS__); \
+    ask++; \
+    char *buffer= (char*)malloc(sizeof(char) * ask); \
+    snprintf(buffer, ask, __VA_ARGS__); \
+    fprintf(stderr, "\n%s:%d: %s Assertion '!%s' [ %s ]\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, #__expression, buffer); \
+    free(buffer); \
+    exit(EXIT_FAILURE); \
+  } \
+} while (0)

